#!/bin/sh

#
#Installation script for Single Sign-On Database
#

# Logging
OPTS=$OPTS" -Dlog4j.configuration=conf/log4j.properties"

# Installation parameters
DB_DIR="./dbfiles"
DB_NAME="wisnetgrid"
DB_USER="wisnetgrid"
DB_PASS="wisnetgrid"


PID=LAST_PID

#
#Installation Directory
#
dir=`dirname $0`
if [ "$dir" != "." ]
then
  INST=`dirname $dir`
else
  pwd | grep -e 'bin$' > /dev/null
  if [ $? = 0 ]
  then
    INST=".."
  else
    INST=`dirname $dir`
  fi
fi

INST=${INST:-.}

cd $INST

if [ -e $PID ] 
then
  if [ -d /proc/$(cat $PID) ]
  then
    echo "A SSO Database instance may be already running with process id "$(cat LAST_PID)
    echo "If this is not the case, delete the file $INST/LAST_PID and re-run this script"
    exit 1
  fi
fi


#
# create data directory for logs
#
if [ ! -e logs  ]
then
  echo "Creating logs directory"
  mkdir -p logs
fi

#
#Java command 
#
JAVA=java

#
#
#Options to the Java VM
#


#
#Memory for the VM
#
MEM=-Xmx128m

#
#put all jars in lib/ on the classpath
#
JARS=lib/*.jar
CP=
for JAR in $JARS ; do 
    CP=$CP:$JAR
done


#
# params
#
PARAM="-install -dbDir "$DB_DIR" -dbName "$DB_NAME" -dbUser "$DB_USER" -dbPass "$DB_PASS

#
#go
#

nohup $JAVA ${MEM} ${OPTS} -cp ${CP} wisnetgrid.security.sso.db.Main ${PARAM} SSO Database > logs/installation.log 2>&1  & echo $! > $PID

ID=$(cat $PID)

printf "\n"
printf "Single Sign-On Database: installing "

stopped="no"
until [ "$stopped" = "" ]; do
  stopped=$(ps -p $ID | grep $ID)
  printf "."
  if [ $? != 0 ] 
  then
    stopped=""
  fi
#  echo -n "."
  sleep 2
done

printf "\n"
cat logs/installation.log
printf "\nRefer to logs/sso-db.log for further details.\n\n"
