#!/bin/sh

#
#Startup script for Single Sign-On Database
#

# Logging
#LOG_FILE="logs/sso-db.log"
OPTS=$OPTS" -Dlog4j.configuration=conf/log4j.properties"

# Force IPv4 usage
#OPTS=$OPTS" -Djava.net.preferIPv4Stack=true"

# Start-up parameters
DB_DIR="./dbfiles"
DB_NAME="wisnetgrid"
DB_PORT="3309"

# Start-up parameters
CONF=" -run -dbDir "$DB_DIR" -dbName "$DB_NAME" -dbPort "$DB_PORT" "

#
#Java command 
JAVA=java

#
#Options to the Java VM
#

#set this one if you have ssl problems and need debug info
#OPTS=$OPTS" -Djavax.net.debug=ssl,handshake"

#
#Memory for the VM
MEM=-Xmx128m

#
#put all jars in lib/ on the classpath
JARS=lib/*.jar
CP=""

#
#Installation Directory
INST=`dirname $0`/".."

PID=logs/LAST_PID

################################################################################

case "$1" in
  start)

  ORG_PWD=`pwd`
  cd $INST

  if [ -e $PID ] 
  then
    if [ -d /proc/$(cat $PID) ]
    then
      echo "A SSO Database instance may be already running with process id "$(cat $PID)
      echo "If this is not the case, delete the file $INST/$PID and re-run this script"
      exit 1
    fi
  fi

#
# create data directory for logs
  if [ ! -e logs  ]
  then
    echo "Creating logs directory"
    mkdir -p logs
  fi

  for JAR in $JARS ; do 
      CP=$CP:$JAR
  done

#
#go
  nohup $JAVA ${MEM} ${OPTS} -cp ${CP} wisnetgrid.security.sso.db.Main ${CONF} SSO DB > logs/startup.log 2>&1  &
  ID=$!
  echo $ID > $PID

  cnt=0
  started="no"
  echo -n "Single Sign-On Database: starting "

  until [ "$started" = "java" ]; do
    echo -n "."
    sleep 1
    started=$(ps --pid $ID -o comm=)  
    cnt=$((cnt + 1))
    if [ $cnt -eq 30 ]
      then
      echo -e "\nSingle Sign-On Database: startup has been taking too long. Check $INST/logs/startup.log."
#      "bin/stop.sh"
       cd $ORG_PWD
       $0 stop
      break
    fi
  done
  printf "\n"

;;


  stop)

  cd $INST

  if [ -s $PID ]
  then
    P=$(cat $PID)
    #cat $PID | xargs kill -SIGTERM
    kill $P

#
# wait for shutdown
    printf "Single Sign-On Database: Shutting down, checking process id $P "

    stopped="no"
    cnt=0
    until [ "$stopped" = "" ]; do
      cnt=$((cnt + 1))
        if [ $cnt -eq 30 ]
        then
          kill -s KILL $P
        fi
      stopped=$(ps -p $P | grep $P)
      echo -n "."
      if [ $? != 0 ] 
      then
        stopped=""
      fi
      sleep 2
    done

  else
    printf "No pid-file found or pid-file is empty!"
  
    echo
  fi

  printf " shutdown complete."

  echo

  rm -f $PID

;;

restart)
  $0 stop
  $0 start
;;

*)
echo "usage: $0 [start|stop|restart]"

esac
